# Amplitude Python SDK
[![PyPI version](https://badge.fury.io/py/amplitude-analytics.svg)](https://badge.fury.io/py/amplitude-analytics)

The official Amplitude backend Python SDK for server-side instrumentation.

## Installation and Quick Start
Please visit the [Developer Center](https://developers.amplitude.com/docs/python-beta) for instructions on installing and using our the SDK.

## Changelog
View the [releases here](https://github.com/amplitude/Amplitude-Python/releases).

## Need Help?
If you have any issues using our SDK, feel free to [create a GitHub issue](https://github.com/amplitude/Amplitude-Python/issues/new) or submit a request on [Amplitude Help](https://help.amplitude.com/hc/en-us/requests/new).
